pub struct RunCmdConfig {
pub runner_cfg: Option<PathBuf>,
pub segger_gdb: Option<bool>,
pub run_name: Option<String>,
pub output_dir: Option<PathBuf>,
pub data_filepath: Option<PathBuf>,
pub binary: PathBuf,
}Fields
runner_cfg: Option<PathBuf>Filepath to a TOML file that contains the runner configuration.
Default: .embedded/runner.toml
segger_gdb: Option<bool>true: Uses RTT commands to communicate with SEGGER GDB instead of the monitor rtt commands from OpenOCD.
This setting overwrites the one optionally set in the runner configuration.
run_name: Option<String>Optional name for the test run.
Default: Absolut filepath of the executed binary.
output_dir: Option<PathBuf>Optional path to a directory that is used to store test results and logs
Default: <binary filepath>_runner (<binary filepath> gets substituted with the filepath set for the binary argument).
data_filepath: Option<PathBuf>Path to look for custom JSON data that is linked with the test run.
Default: .embedded/test_run_data.json
binary: PathBufFilepath to the binary that should be run on the embedded device.